Merge branch 'fix_missing_vector_bits' of https://github.com/ROCm-Developer-Tools/HIP into fix_missing_vector_bits
[ROCm/hip commit: 7d96318828]
Tá an tiomantas seo le fáil i:
@@ -683,32 +683,60 @@ __MAKE_VECTOR_TYPE__(longlong, long long);
|
||||
__MAKE_VECTOR_TYPE__(float, float);
|
||||
__MAKE_VECTOR_TYPE__(double, double);
|
||||
|
||||
#define DECLOP_MAKE_ONE_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x) { type r = {x}; return r; }
|
||||
#if defined(__cplusplus)
|
||||
#define DECLOP_MAKE_ONE_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x) { return type{x}; }
|
||||
|
||||
#define DECLOP_MAKE_TWO_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y) { type r = {x, y}; return r; }
|
||||
#define DECLOP_MAKE_TWO_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y) { return type{x, y}; }
|
||||
|
||||
#define DECLOP_MAKE_THREE_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y, comp z) { type r = {x, y, z}; return r; }
|
||||
#define DECLOP_MAKE_THREE_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y, comp z) { return type{x, y, z}; }
|
||||
|
||||
#define DECLOP_MAKE_FOUR_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y, comp z, comp w) { \
|
||||
type r = {x, y, z, w}; \
|
||||
return r; \
|
||||
}
|
||||
#define DECLOP_MAKE_FOUR_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y, comp z, comp w) { \
|
||||
return type{x, y, z, w}; \
|
||||
}
|
||||
#else
|
||||
#define DECLOP_MAKE_ONE_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x) { type r = {x}; return r; }
|
||||
|
||||
#define DECLOP_MAKE_TWO_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y) { type r = {x, y}; return r; }
|
||||
|
||||
#define DECLOP_MAKE_THREE_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y, comp z) { type r = {x, y, z}; return r; }
|
||||
|
||||
#define DECLOP_MAKE_FOUR_COMPONENT(comp, type) \
|
||||
__device__ __host__ \
|
||||
static \
|
||||
inline \
|
||||
type make_##type(comp x, comp y, comp z, comp w) { \
|
||||
type r = {x, y, z, w}; \
|
||||
return r; \
|
||||
}
|
||||
#endif
|
||||
|
||||
DECLOP_MAKE_ONE_COMPONENT(unsigned char, uchar1);
|
||||
DECLOP_MAKE_TWO_COMPONENT(unsigned char, uchar2);
|
||||
|
||||
Tagairt in Eagrán Nua
Cuir bac ar úsáideoir